==> readmeter-3.1.3.jar: readmeter/sqls/readmeterinfo/getPcHandMeter.sql <==
select h.*,
       dp.f_price,
       case when dp.f_price is not null then Convert(decimal(18,2),isnull(h.f_oughtamount,0)*isnull(dp.f_price,0))
            else 0 end f_ought_money,
       case when isnull(uf.f_capacity, 0) > 0 then uf.f_capacity else gm.f_capacity end f_capacity, --表最大量程
       ui.f_comments f_phone_comments,
       ui.f_book_no,
       ui.f_user_level,
       ui.f_rent_phone,
       ui.f_olduserinfo_code,
       isnull(h4.f_last_startbase,0) f_last_startbase,
       isnull(h4.f_last_gas,0) f_last_gas,
       h2.f_last_oughtamount f_last_oughtamount,
       ave1.f_ave_gas f_ave_gas,
       h5.f_oughtfee as f_real_oughtfee
from(
    select * from t_handplan
    where f_inputtor = '{f_inputtor}'
    and    SUBSTRING(CONVERT(varchar,f_hand_date,23),0,5) = year(getdate())
    and f_meter_state = '未抄表'
    and f_hand_state = '有效'
) h left join
(
    select f_user_level,f_rent_phone,f_comments,f_userinfo_id,f_olduserinfo_code,f_book_no from t_userinfo where f_user_state='正常'
) ui on h.f_userinfo_id=ui.f_userinfo_id
left join (
	select f_userfiles_id,

	    cast(sum(f_oughtamount)/(isnull(DATEDIFF (month , min(f_input_date),max(f_input_date)),0)+1) as   numeric(9,2))
     f_ave_gas,

	        max(id) maxid
    from t_handplan
    where f_hand_state='有效' and f_meter_state='已抄表' group by  f_userfiles_id
)ave1 on h.f_userfiles_id=ave1.f_userfiles_id
left join (select id,f_oughtamount f_last_oughtamount from t_handplan)h2 on ave1.maxid=h2.id
left join (
    select
        f_last_tablebase f_last_startbase,f_oughtamount f_last_gas,f_userfiles_id
    from t_handplan t2
    where id in (select max(id)
                 from t_handplan
                 where f_userfiles_id = t2.f_userfiles_id and f_hand_state = '有效' and f_meter_state='已抄表'
                 GROUP BY f_userfiles_id)
) h4 on h.f_userfiles_id = h4.f_userfiles_id
left join t_userfiles uf on h.f_userfiles_id=uf.f_userfiles_id
left join (
          select
              f_userfiles_id,
              sum(f_oughtfee) f_oughtfee,
              0 f_overdue
              from (
                  select
                  h.f_userfiles_id,
                  h.f_oughtamount,
                  isnull(f_debt_money,0) f_debt_money,
                  h.f_oughtfee-isnull(f_debt_money,0) f_oughtfee,
                  u.f_balance,
                  u.f_userinfo_code
                  from t_handplan h left join (
                      select f_hand_id,sum(f_debt_money) f_debt_money
                      from t_sellinghand group by f_hand_id
                  ) sh on h.id = sh.f_hand_id
                  left join t_userinfo u on h.f_userinfo_id = u.f_userinfo_id
                  where f_whether_pay='否' and f_meter_state='已抄表' and f_hand_state='有效'
          ) s
          group by s.f_userfiles_id
) h5 on uf.f_userfiles_id = h5.f_userfiles_id
left join t_gasmodel gm on uf.f_gasmodel_id = gm.id
left join (select * from t_stairprice where f_state='有效' and f_price_type='固定气价' and getdate()>=f_perform_date and getdate()<=f_end_date)	sp on uf.f_price_id=sp.f_price_id
LEFT JOIN  t_detailprice dp ON sp.id = dp.f_stairprice_id and dp.f_price_name='1'
where f_table_state in ('正常','停用')
order by h.id asc

==> readmeter-3.1.22.jar: readmeter/sqls/readmeterinfo/getPcHandMeter.sql <==
select h.*,
       dp.f_price,
       case when dp.f_price is not null then Convert(decimal(18,2),isnull(h.f_oughtamount,0)*isnull(dp.f_price,0))
            else 0 end f_ought_money,
       case when isnull(uf.f_capacity, 0) > 0 then uf.f_capacity else gm.f_capacity end f_capacity, --表最大量程
       ui.f_comments f_phone_comments,
       ui.f_book_no,
       ui.f_user_level,
       uf.f_bqf_state,
       uf.f_defendcard,
       uf.f_total_gas,
       uf.f_total_fee,
       ui.f_rent_phone,
       ui.f_olduserinfo_code,
       isnull(h4.f_last_gas,0) f_last_gas,
       h2.f_last_oughtamount f_last_oughtamount,
       ave1.f_ave_gas f_ave_gas,
       h5.f_oughtfee as f_real_oughtfee
from(
    select * from t_handplan
    where f_inputtor = '{f_inputtor}'
    and    SUBSTRING(CONVERT(varchar,f_hand_date,23),0,5) = year(getdate())
    and f_meter_state = '未抄表'
    and f_hand_state = '有效'
) h left join
(
    select f_user_level,f_rent_phone,f_comments,f_userinfo_id,f_olduserinfo_code,f_book_no from t_userinfo where f_user_state='正常'
) ui on h.f_userinfo_id=ui.f_userinfo_id
left join (
	select f_userfiles_id,

	    cast(sum(f_oughtamount)/(isnull(DATEDIFF (month , min(f_input_date),max(f_input_date)),0)+1) as   numeric(9,2))
     f_ave_gas,

	        max(id) maxid
    from t_handplan
    where f_hand_state='有效' and f_meter_state='已抄表' group by  f_userfiles_id
)ave1 on h.f_userfiles_id=ave1.f_userfiles_id
left join (select id,f_oughtamount f_last_oughtamount from t_handplan)h2 on ave1.maxid=h2.id
left join (
    select
        f_last_tablebase f_last_startbase,f_oughtamount f_last_gas,f_userfiles_id
    from t_handplan t2
    where id in (select max(id)
                 from t_handplan
                 where f_userfiles_id = t2.f_userfiles_id and f_hand_state = '有效' and f_meter_state='已抄表'
                 GROUP BY f_userfiles_id)
) h4 on h.f_userfiles_id = h4.f_userfiles_id
left join t_userfiles uf on h.f_userfiles_id=uf.f_userfiles_id
left join (
          select
              f_userfiles_id,
              sum(f_oughtfee) f_oughtfee,
              0 f_overdue
              from (
                  select
                  h.f_userfiles_id,
                  h.f_oughtamount,
                  isnull(f_debt_money,0) f_debt_money,
                  h.f_oughtfee-isnull(f_debt_money,0) f_oughtfee,
                  u.f_balance,
                  u.f_userinfo_code
                  from t_handplan h left join (
                      select f_hand_id,sum(f_debt_money) f_debt_money
                      from t_sellinghand group by f_hand_id
                  ) sh on h.id = sh.f_hand_id
                  left join t_userinfo u on h.f_userinfo_id = u.f_userinfo_id
                  where f_whether_pay='否' and f_meter_state='已抄表' and f_hand_state='有效'
          ) s
          group by s.f_userfiles_id
) h5 on uf.f_userfiles_id = h5.f_userfiles_id
left join t_gasmodel gm on uf.f_gasmodel_id = gm.id
left join (select * from t_stairprice where f_state='有效' and f_price_type='固定气价' and getdate()>=f_perform_date and getdate()<=f_end_date)	sp on uf.f_price_id=sp.f_price_id
LEFT JOIN  t_detailprice dp ON sp.id = dp.f_stairprice_id and dp.f_price_name='1'
where f_table_state in ('正常','停用')
order by h.id asc
